<?php
/**
 * Initialize the options before anything else.
 */
add_action( 'admin_init', 'custom_theme_options', 1 );

/**
 * Build the custom settings & update OptionTree.
 */
function custom_theme_options() {
  /**
   * Get a copy of the saved settings array.
   */
  $saved_settings = get_option( 'option_tree_settings', array() );

  /**
   * Custom settings array that will eventually be
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array(
    'contextual_help' => array(
      'content'       => array(
        array(
          'id'        => 'general_help',
          'title'     => esc_html__('General', 'asana'),
          'content'   => esc_html__('Theme options here.', 'asana')
        )
      ),
      'sidebar'       => '',
    ),
    'sections'        => array(
      array(
        'id'          => 'general',
        'title'       => esc_html__('General', 'asana')
      ),
      array(
        'id'          => 'logo',
        'title'       => esc_html__('Logo settings', 'asana')
      ),
      array(
        'id'          => 'color',
        'title'       => esc_html__('Colour schemes', 'asana')
      ),
      array(
        'id'          => 'header',
        'title'       => esc_html__('Styles of navigation bar', 'asana')
      ),
      array(
        'id'          => 'fonts',
        'title'       => esc_html__('Fonts', 'asana')
      ),
      array(
        'id'          => 'headers',
        'title'       => esc_html__('Page headers settings', 'asana')
      ),
      array(
        'id'          => 'home',
        'title'       => esc_html__('"Home" page settings', 'asana')
      ),
      array(
        'id'          => 'contact',
        'title'       => esc_html__('"Contact" page settings', 'asana')
      ),
      array(
        'id'          => 'mailchimp',
        'title'       => esc_html__('Mailchimp settings', 'asana')
      ),
      array(
        'id'          => 'socialapp',
        'title'       => esc_html__('Social apps and settings', 'bauhaus')
      ),
      array(
        'id'          => 'social',
        'title'       => esc_html__('Socials', 'asana')
      )
    ),
    'settings'        => array(
      array(
        'id'          => 'uni_single_post_with_sidebar',
        'label'       => esc_html__( 'Enable/Disable displaying single post with a sidebar', 'asana' ),
        'desc'        => esc_html__( 'The default view is without a sidebar. But you can enable displaying sidebar here. This is a global option and it works for the whole website', 'asana' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_display_similar_posts',
        'label'       => esc_html__( 'Enable/Disable displaying similar posts on single post page', 'asana' ),
        'desc'        => esc_html__( 'This is a global option and it works for the whole website', 'asana' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_prod_tax_exclude',
        'label'       => __( 'Excluded categories of products', 'asana' ),
        'desc'        => __( 'Check here those categories which you want to hide and want to exclude from the list of categories on the website (shop page and single product page). However, they still will be accessible directly!', 'asana' ),
        'std'         => '',
        'type'        => 'taxonomy-checkbox',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => 'product_cat',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_ajax_scroll_enable_products',
        'label'       => sprintf( esc_html__( 'Enable/disable infinite ajax scroll for %s', 'asana' ), esc_html__('products', 'asana') ),
        'desc'        => sprintf( esc_html__( 'You can switch between regular pagination and infinite ajax scroll feature, when all you %s will be loaded via ajax on archive pages and also automatically when user scrolls to the end of the current page.', 'asana' ), esc_html__('products', 'asana') ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_ajax_scroll_enable_posts',
        'label'       => sprintf( esc_html__( 'Enable/disable infinite ajax scroll for %s', 'asana' ), esc_html__('posts', 'asana') ),
        'desc'        => sprintf( esc_html__( 'You can switch between regular pagination and infinite ajax scroll feature, when all you %s will be loaded via ajax on archive pages and also automatically when user scrolls to the end of the current page.', 'asana' ), esc_html__('posts', 'asana') ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_ajax_scroll_enable_events',
        'label'       => sprintf( esc_html__( 'Enable/disable infinite ajax scroll for %s', 'asana' ), esc_html__('events', 'asana') ),
        'desc'        => sprintf( esc_html__( 'You can switch between regular pagination and infinite ajax scroll feature, when all you %s will be loaded via ajax on archive pages and also automatically when user scrolls to the end of the current page.', 'asana' ), esc_html__('events', 'asana') ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_events_textblock',
        'label'       => esc_html__( 'Events Textblock', 'asana' ),
        'desc'        => esc_html__( 'Below are some settings related to CPT "Events" and its archives.', 'asana' ),
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_events_page',
        'label'       => esc_html__( 'Events page', 'asana' ),
        'desc'        => esc_html__( 'Select your Events page. This page is like a blog, but for events. A link to this page will be added on a single event page. It acts like a global option and this value can be overrided for every single event page. It is useful if you have several different pages with events.', 'asana' ),
        'std'         => '',
        'type'        => 'custom-post-type-select',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => 'page',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_events_join_on',
        'label'       => esc_html__( 'Enable/disable "join event" functionality', 'asana' ),
        'desc'        => esc_html__( 'You can enable/disable "join" functionality on single event pages. Enabling adds "Join" button to all single event pages. This button opens modal window with form that can be used as registration form. After form submit a site owner and a user receive emails with entered information. <strong>Important: no data from this form will be stored in DB. It just sends emails!</strong>', 'asana' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_footer_textblock',
        'label'       => esc_html__( 'Footer Textblock', 'asana' ),
        'desc'        => esc_html__( 'Below are some settings for the footer.', 'asana' ),
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_footer_text',
        'label'       => esc_html__( 'Text in the footer', 'asana' ),
        'desc'        => esc_html__( 'Add your own text to the footer', 'asana' ),
        'std'         => '',
        'type'        => 'textarea',
        'section'     => 'general',
        'rows'        => '5',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_logo_textblock',
        'label'       => esc_html__( 'Textblock', 'asana' ),
        'desc'        => esc_html__( 'You can swicth between two options how your logo has to be shown: by using two .png files of the same image but in different colours or by using one image in SVG format. We also recommend you to use images with transparent background for the best effect!', 'asana' ),
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'logo',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_logo_type',
        'label'       => esc_html__( 'Switch to logo in SVG format?', 'asana' ),
        'desc'        => esc_html__( '"On" means that you want to use logo in SVG format. "Off" means that you want to use two uploaded images.', 'asana' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'logo',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_logo_a',
        'label'       => esc_html__( 'Logo A', 'asana' ),
        'desc'        => esc_html__( 'Upload the first variant of your logo. By default, the header initially is white. So, it is a good idea to add a dark variant of your logo.', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'logo',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_logo_b',
        'label'       => esc_html__( 'Logo B', 'asana' ),
        'desc'        => esc_html__( 'Upload the second variant of your logo. Now, it is better to add a light variant of your logo. Something that contrasting with the first variant.', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'logo',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_logo_height',
        'label'       => esc_html__( 'Height of the logo', 'asana' ),
        'desc'        => sprintf( esc_html__( 'Define custom height that fits best your needs. Width of the logo will be changed proportionally. %sI would suggest you to upload at least twice bigger logo and define that height that you actually want to use. For instance, you want to use logo with height 70 px, then define here "70" but upload an image with height 140 px or larger. In this case, logo will be displayed with height 70 px every time, but you will also see nice unblurred image on retina display. Important: "OTF Regenerate Thumbnails" must be activated in order to use this feature!%s', 'asana' ), '<strong>', '</strong>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'logo',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_menu_top_margin',
        'label'       => esc_html__( 'Margin top for the main menu', 'asana' ),
        'desc'        => esc_html__( 'Define this value if you use custom logo height. You can adjust margin top of the main menu with this setting. Default is: "37"', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'logo',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_logo_svg',
        'label'       => esc_html__( 'Logo in SVG format', 'asana' ),
        'desc'        => esc_html__( 'Add the code here.', 'asana' ),
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'logo',
        'rows'        => '10',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_color_schemes',
        'label'       => esc_html__( 'Colour schemes', 'asana' ),
        'desc'        => esc_html__( 'You can choose a desired colour scheme here. The default is the first one.', 'asana' ),
        'std'         => 'default',
        'type'        => 'radio-image',
        'section'     => 'color',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_nav_white_enable',
        'label'       => esc_html__( 'Make nav bar always white and fixed?', 'asana' ),
        'desc'        => esc_html__( 'Turn on this option and nav bar will always stay at the top of the page and have a white (or custom, see below) background.', 'asana' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'header',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_nav_floating_custom_styles_enable',
        'label'       => esc_html__( 'Enable custom styles for floating version of navigation bar?', 'asana' ),
        'desc'        => esc_html__( 'This type of navigation bar is set by default. Turn this option on in order to apply custom styles or turn it off to reset to theme\'s default styles.', 'asana' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'header',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_nav_white_enable:is(off)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_floating_nav_bg_color_transparent',
        'label'       => esc_html__( 'Background colour of floating nav bar in transparent state', 'asana' ),
        'desc'        => esc_html__( 'Default is "rgba(255,255,255,0.01)" which means fully transparent. However you can choose any colour and opacity.', 'asana' ),
        'std'         => 'rgba(255,255,255,0.01)',
        'type'        => 'colorpicker-opacity',
        'section'     => 'header',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_nav_white_enable:is(off),uni_nav_floating_custom_styles_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_floating_nav_border_transparent',
        'label'       => esc_html__( 'Colour of the bottom border of floating nav bar in transparent state', 'asana' ),
        'desc'        => esc_html__( 'Default is "rgba(255,255,255,0.2)" which is white with 0.2 opacity. However you can choose any colour and opacity.', 'asana' ),
        'std'         => 'rgba(255,255,255,0.2)',
        'type'        => 'colorpicker-opacity',
        'section'     => 'header',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_nav_white_enable:is(off),uni_nav_floating_custom_styles_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_floating_nav_link_color_transparent',
        'label'       => esc_html__( 'Colour of links in floating nav bar in transparent state', 'asana' ),
        'desc'        => esc_html__( 'Default is "#ffffff". You can choose another colour.', 'asana' ),
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'header',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_nav_white_enable:is(off),uni_nav_floating_custom_styles_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_floating_nav_link_hover_color_transparent',
        'label'       => esc_html__( 'Colour of links in hovered state in floating nav bar in transparent state', 'asana' ),
        'desc'        => esc_html__( 'Default is "#ffffff". You can choose another colour.', 'asana' ),
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'header',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_nav_white_enable:is(off),uni_nav_floating_custom_styles_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_floating_nav_bg_color',
        'label'       => esc_html__( 'Background colour of floating nav bar in non-transparent state', 'asana' ),
        'desc'        => esc_html__( 'Default is "rgba(255,255,255,1)" which means "white" with no opacity. However you can choose any colour and opacity.', 'asana' ),
        'std'         => 'rgba(255,255,255,1)',
        'type'        => 'colorpicker-opacity',
        'section'     => 'header',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_nav_white_enable:is(off),uni_nav_floating_custom_styles_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_floating_nav_link_color',
        'label'       => esc_html__( 'Colour of links in floating nav bar in non-transparent state', 'asana' ),
        'desc'        => esc_html__( 'Default is "#7f7f7f". You can choose another colour.', 'asana' ),
        'std'         => '#7f7f7f',
        'type'        => 'colorpicker',
        'section'     => 'header',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_nav_white_enable:is(off),uni_nav_floating_custom_styles_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_floating_nav_link_hover_color',
        'label'       => esc_html__( 'Colour of links in hovered state in floating nav bar in non-transparent state', 'asana' ),
        'desc'        => esc_html__( 'Default is "#333333". You can choose another colour.', 'asana' ),
        'std'         => '#333333',
        'type'        => 'colorpicker',
        'section'     => 'header',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_nav_white_enable:is(off),uni_nav_floating_custom_styles_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_sticky_nav_bg_color',
        'label'       => esc_html__( 'Background colour of fixed nav bar', 'asana' ),
        'desc'        => esc_html__( 'Default is "white". You can choose another colour.', 'asana' ),
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'header',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_nav_white_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_sticky_nav_link_color',
        'label'       => esc_html__( 'Colour of links in fixed nav bar', 'asana' ),
        'desc'        => esc_html__( 'Default is "#7f7f7f". You can choose another colour.', 'asana' ),
        'std'         => '#7f7f7f',
        'type'        => 'colorpicker',
        'section'     => 'header',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_nav_white_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_sticky_nav_link_hover_color',
        'label'       => esc_html__( 'Colour of links in hovered state in fixed nav bar', 'asana' ),
        'desc'        => esc_html__( 'Default is "#333333". You can choose another colour.', 'asana' ),
        'std'         => '#333333',
        'type'        => 'colorpicker',
        'section'     => 'header',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_nav_white_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_google_fonts',
        'label'       => esc_html__( 'Custom Google Fonts', 'asana' ),
        'desc'        => esc_html__( 'You can define custom Google fonts here. Please, use the first for regular text and the second for headings. Default are: Lato (300, 300italic, regular) and Montserrat (700, regular)', 'asana' ),
        'std'         => array(
          array(
            'family'    => 'lato',
            'variants'  => array( '300', '300italic', 'regular' ),
            'subsets'   => array( 'latin' )
          ),
          array(
            'family'    => 'montserrat',
            'variants'  => array( '700', 'regular' ),
            'subsets'   => array( 'latin' )
          )
        ),
        'type'        => 'google-fonts',
        'section'     => 'fonts',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_shop_header_bg',
        'label'       => esc_html__( 'Page header image on Shop/Product archives/Single product pages', 'asana' ),
        'desc'        => esc_html__( 'This image will be shown on the top of the Shop/Product archives/Single product pages', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_shop_header_title',
        'label'       => esc_html__( 'Page header title on Shop/Single product pages', 'asana' ),
        'desc'        => esc_html__( 'This title will be shown on the top of the Shop/Single product pages', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_shop_header_title_color',
        'label'       => esc_html__( 'Colour of page header title on Shop/Single product pages', 'asana' ),
        'desc'        => esc_html__( 'Default is "white". You can choose another colour for this text.', 'asana' ),
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_cart_header_bg',
        'label'       => esc_html__( 'Page header image on Cart page', 'asana' ),
        'desc'        => esc_html__( 'This image will be shown on the top of the Cart page', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_cart_header_title',
        'label'       => esc_html__( 'Page header title on Cart page', 'asana' ),
        'desc'        => esc_html__( 'This title will be shown on the top of the Cart page', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_cart_header_title_color',
        'label'       => esc_html__( 'Colour of page header title on Cart page', 'asana' ),
        'desc'        => esc_html__( 'Default is "white". You can choose another colour for this text.', 'asana' ),
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_checkout_header_bg',
        'label'       => esc_html__( 'Page header image on Checkout page', 'asana' ),
        'desc'        => esc_html__( 'This image will be shown on the top of the Checkout page', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_checkout_header_title',
        'label'       => esc_html__( 'Page header title on Checkout page', 'asana' ),
        'desc'        => esc_html__( 'This title will be shown on the top of the Checkout page', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_checkout_header_title_color',
        'label'       => esc_html__( 'Colour of page header title on Checkout page', 'asana' ),
        'desc'        => esc_html__( 'Default is "white". You can choose another colour for this text.', 'asana' ),
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_about_header_bg',
        'label'       => esc_html__( 'Page header image on "About" page', 'asana' ),
        'desc'        => esc_html__( 'This image will be shown on the top of "About" page', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_about_header_title',
        'label'       => esc_html__( 'Page header title on "About" page', 'asana' ),
        'desc'        => esc_html__( 'This title will be shown on the top of "About" page', 'asana' ),
        'std'         => 'About Our Studio',
        'type'        => 'text',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_about_header_title_color',
        'label'       => esc_html__( 'Colour of page header title on "About" page', 'asana' ),
        'desc'        => esc_html__( 'Default is "white". You can choose another colour for this text.', 'asana' ),
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_events_header_bg',
        'label'       => esc_html__( 'Page header image on "Events" page', 'asana' ),
        'desc'        => esc_html__( 'This image will be shown on the top of "Events" page', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_events_header_title',
        'label'       => esc_html__( 'Page header title on "Events" page', 'asana' ),
        'desc'        => esc_html__( 'This title will be shown on the top of "Events" page', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_events_header_title_color',
        'label'       => esc_html__( 'Colour of page header title on "Events" page', 'asana' ),
        'desc'        => esc_html__( 'Default is "white". You can choose another colour for this text.', 'asana' ),
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_contact_header_bg',
        'label'       => esc_html__( 'Page header image on Contact page', 'asana' ),
        'desc'        => esc_html__( 'This image will be shown on the top of the Contact page', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_contact_header_title',
        'label'       => esc_html__( 'Page header title on Contact page', 'asana' ),
        'desc'        => esc_html__( 'This title will be shown on the top of the Contact page', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_contact_header_title_color',
        'label'       => esc_html__( 'Colour of page header title on Contact page', 'asana' ),
        'desc'        => esc_html__( 'Default is "white". You can choose another colour for this text.', 'asana' ),
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'headers',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_rev_slider_enable',
        'label'       => esc_html__( 'Show/hide Revolution Slider on home page', 'asana' ),
        'desc'        => esc_html__( 'Important: you must activate "Revolution Slider" plugin first (bundled with a theme) and create a slider with alias "home"!', 'asana' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_slider_enable',
        'label'       => esc_html__( 'Show/hide the slider on home page', 'asana' ),
        'desc'        => esc_html__( 'A simple yet functional slider. Utilises custom post types "Home slides". Each post under "Home slides" acts like a slide for this slider.', 'asana' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_about_enable',
        'label'       => esc_html__( 'Show/hide the "About Us" block on home page', 'asana' ),
        'desc'        => '',
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_about_title',
        'label'       => esc_html__( 'Title for the "About Us" block on home page', 'asana' ),
        'desc'        => esc_html__( 'Add custom title for this block. You may use html tags: <code>br, em, strong</code>', 'asana' ),
        'std'         => esc_html__( 'About Us', 'asana' ),
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_about_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_about_text',
        'label'       => esc_html__( 'Custom text for the "About Us" block on home page', 'asana' ),
        'desc'        => esc_html__( 'Add custom text for the "About Us" block on home page. You may use html tags: <code>br, em, strong, a</code>', 'asana' ),
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'home',
        'rows'        => '5',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_about_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_about_image',
        'label'       => esc_html__( 'Image for "About Us" block on home page', 'asana' ),
        'desc'        => esc_html__( 'Upload an image for "About Us" block on home page', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => 'uni_home_about_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_about_more_link_url',
        'label'       => esc_html__( 'URL for a "view more" link for "About Us" block on home page', 'asana' ),
        'desc'        => esc_html__( 'Add custom URI', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_about_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_about_more_link_text',
        'label'       => esc_html__( 'Custom text for a "view more" link for "About Us" block on home page', 'asana' ),
        'desc'        => esc_html__( 'Add custom text. Default is: "view more"', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_about_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_enable',
        'label'       => esc_html__( 'Show/hide the grid with custom content on home page', 'asana' ),
        'desc'        => '',
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_promo_custom_textblock',
        'label'       => esc_html__( '6 promo items with a custom content in unique grid on home page', 'asana' ),
        'desc'        => esc_html__( 'Below you can see options to add 6 promo items with custom content in each. You are able to add custom title, text and image for every these items. Important: please keep in mind that you have to fill options for the first item or for all six items, otherwise this grid won\'t look nice. And it is required to add an URI for the item that you want to be displayed! So, to disable specific item - delete URL option for it.', 'asana' ),
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_title_one',
        'label'       => esc_html__( 'Title for the first item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom title for the first item in the grid. You may use html tags: <code>br, em, strong</code>', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_text_one',
        'label'       => esc_html__( 'Custom text for the first item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom text for the first item in the grid. You may use html tags: <code>br, em, strong, a</code>', 'asana' ),
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'home',
        'rows'        => '5',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_image_one',
        'label'       => esc_html__( 'Image for the first item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Upload an image for the first item in the grid. Thumbnail 684x684 will be shown here.', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_uri_one',
        'label'       => esc_html__( 'URI for the first item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom URI for the first item in the grid', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_uri_one_label',
        'label'       => esc_html__( 'Custom text for a "view more" link for the first item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom text. Default is: "view more"', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_title_two',
        'label'       => esc_html__( 'Title for the second item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom title for the second item in the grid. You may use html tags: <code>br, em, strong</code>', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_text_two',
        'label'       => esc_html__( 'Custom text for the second item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom text for the second item in the grid. You may use html tags: <code>br, em, strong</code>. This block is built as a link, so you are not allowed to use <code>a</code> here.', 'asana' ),
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'home',
        'rows'        => '5',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_image_two',
        'label'       => esc_html__( 'Image for the second item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Upload an image for the second item in the grid. Thumbnail 342x342 will be shown here.', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_uri_two',
        'label'       => esc_html__( 'URI for the second item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom URI for the second item in the grid', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_uri_two_label',
        'label'       => esc_html__( 'Custom text for a "view more" link for the second item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom text. Default is: "view more"', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_title_three',
        'label'       => esc_html__( 'Title for the third item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom title for the third item in the grid. You may use html tags: <code>br, em, strong</code>', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_text_three',
        'label'       => esc_html__( 'Custom text for the third item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom text for the third item in the grid. You may use html tags: <code>br, em, strong</code>. This block is built as a link, so you are not allowed to use <code>a</code> here.', 'asana' ),
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'home',
        'rows'        => '5',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_image_three',
        'label'       => esc_html__( 'Image for the third item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Upload an image for the third item in the grid. Thumbnail 342x342 will be shown here.', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_uri_three',
        'label'       => esc_html__( 'URI for the third item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom URI for the third item in the grid', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_uri_three_label',
        'label'       => esc_html__( 'Custom text for a "view more" link for the third item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom text. Default is: "view more"', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_title_four',
        'label'       => esc_html__( 'Title for the fourth item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom title for the fourth item in the grid. You may use html tags: <code>br, em, strong</code>', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_text_four',
        'label'       => esc_html__( 'Custom text for the fourth item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom text for the fourth item in the grid. You may use html tags: <code>br, em, strong</code>. This block is built as a link, so you are not allowed to use <code>a</code> here.', 'asana' ),
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'home',
        'rows'        => '5',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_image_four',
        'label'       => esc_html__( 'Image for the fourth item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Upload an image for the fourth item in the grid. Thumbnail 342x342 will be shown here.', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_uri_four',
        'label'       => esc_html__( 'URI for the fourth item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom URI for the fourth item in the grid', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_uri_four_label',
        'label'       => esc_html__( 'Custom text for a "view more" link for the fourth item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom text. Default is: "view more"', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_title_five',
        'label'       => esc_html__( 'Title for the fifth item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom title for the fifth item in the grid. You may use html tags: <code>br, em, strong</code>', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_text_five',
        'label'       => esc_html__( 'Custom text for the fifth item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom text for the fifth item in the grid. You may use html tags: <code>br, em, strong</code>. This block is built as a link, so you are not allowed to use <code>a</code> here.', 'asana' ),
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'home',
        'rows'        => '5',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_image_five',
        'label'       => esc_html__( 'Image for the fifth item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Upload an image for the fifth item in the grid. Thumbnail 342x342 will be shown here.', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_uri_five',
        'label'       => esc_html__( 'URI for the fifth item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom URI for the fifth item in the grid', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_uri_five_label',
        'label'       => esc_html__( 'Custom text for a "view more" link for the fifth item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom text. Default is: "view more"', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_title_six',
        'label'       => esc_html__( 'Title for the sixth item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom title for the sixth item in the grid. You may use html tags: <code>br, em, strong</code>', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_text_six',
        'label'       => esc_html__( 'Custom text for the sixth item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom text for the sixth item in the grid. You may use html tags: <code>br, em, strong</code>. This block is built as a link, so you are not allowed to use <code>a</code> here.', 'asana' ),
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'home',
        'rows'        => '5',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_image_six',
        'label'       => esc_html__( 'Image for the sixth item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Upload an image for the sixth item in the grid. Thumbnail 684x684 will be shown here.', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_uri_six',
        'label'       => esc_html__( 'URI for the sixth item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom URI for the sixth item in the grid', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_custom_uri_six_label',
        'label'       => esc_html__( 'Custom text for a "view more" link for the sixth item in the grid', 'asana' ),
        'desc'        => esc_html__( 'Add custom text. Default is: "view more"', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_custom_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_grid_enable',
        'label'       => esc_html__( 'Show/hide the grid with posts on home page', 'asana' ),
        'desc'        => '',
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_promo_posts_textblock',
        'label'       => esc_html__( '6 promo posts for unique grid on home page', 'asana' ),
        'desc'        => esc_html__( 'Below you can see 6 dropdowns. Please, select 6 posts here, these posts will be shown on home page in unique grid below the slider. Otherwise, 6 recent posts will be shown. Attention: if you don\'t have at least 6 published posts, this section doesn\'t appear at all! But first of all you can decide whether display or not this grid at all.', 'asana' ),
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_posts_1',
        'label'       => esc_html__( 'Post #1', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'custom-post-type-select',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => 'post',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_posts_2',
        'label'       => esc_html__( 'Post #2', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'custom-post-type-select',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => 'post',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_posts_3',
        'label'       => esc_html__( 'Post #3', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'custom-post-type-select',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => 'post',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_posts_4',
        'label'       => esc_html__( 'Post #4', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'custom-post-type-select',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => 'post',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_posts_5',
        'label'       => esc_html__( 'Post #5', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'custom-post-type-select',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => 'post',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_posts_6',
        'label'       => esc_html__( 'Post #6', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'custom-post-type-select',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => 'post',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_grid_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_membership_cards_enable',
        'label'       => esc_html__( 'Show/hide membership cards section on home page', 'asana' ),
        'desc'        => '',
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_membership_cards_title',
        'label'       => esc_html__( 'Title for membership cards section on home page', 'asana' ),
        'desc'        => esc_html__( 'Add title for membership cards section on home page', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_membership_cards_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_ordernow_btn_membership_cards_enable',
        'label'       => esc_html__( 'Enable/disable displaying of "Orer Now" button for items on home page', 'asana' ),
        'desc'        => esc_html__( 'This option works only for items displayed on homepage and only for items which are posts in CPT "Price"', 'asana' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_membership_cards_enable:is(on),uni_home_membership_cards_subscriptions_enable:is(off)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_membership_cards_subscriptions_enable',
        'label'       => esc_html__( 'Enable/disable support of WooCommerce Subscriptions extension', 'asana' ),
        'desc'        => esc_html__( 'You can enable the support of WooCommerce Subscriptions extension if you plan to use it (not bundled with the theme; you have to buy it separately if you want it!). So, instead of using built-in custom post type Prices you can decide to display "subscription" type products here. Just choose three products of this type to display here or the three most recent will be shown instead. Notice: "Order Now" buttons will be linked to single pages of these products.', 'asana' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_membership_cards_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_mc_subscription_prod_left',
        'label'       => esc_html__( 'Left product-subscription', 'asana' ),
        'desc'        => esc_html__( 'Choose here product type subscription which will be shown on the left (or first on most narrow screens). Notice: all your products are displayed in the dropdown, not only subscriptions! So, you have to know on your own what product type is for a particular product. Also, I would recommend to make this product hidden in all catalogs (it is a built in option of WC and it is located near "Publish" button on single product edit page).', 'asana' ),
        'std'         => '',
        'type'        => 'custom-post-type-select',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => 'product',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_membership_cards_enable:is(on),uni_home_membership_cards_subscriptions_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_mc_subscription_prod_center',
        'label'       => esc_html__( 'Centre product-subscription', 'asana' ),
        'desc'        => esc_html__( 'Choose here product type subscription which will be shown on the centre (or second on most narrow screens). Notice: all your products are displayed in the dropdown, not only subscriptions! So, you have to know on your own what product type is for a particular product. Also, I would recommend to make this product hidden in all catalogs (it is a built in option of WC and it is located near "Publish" button on single product edit page).', 'asana' ),
        'std'         => '',
        'type'        => 'custom-post-type-select',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => 'product',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_membership_cards_enable:is(on),uni_home_membership_cards_subscriptions_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_mc_subscription_prod_right',
        'label'       => esc_html__( 'Right product-subscription', 'asana' ),
        'desc'        => esc_html__( 'Choose here product type subscription which will be shown on the right (or third on most narrow screens). Notice: all your products are displayed in the dropdown, not only subscriptions! So, you have to know on your own what product type is for a particular product. Also, I would recommend to make this product hidden in all catalogs (it is a built in option of WC and it is located near "Publish" button on single product edit page).', 'asana' ),
        'std'         => '',
        'type'        => 'custom-post-type-select',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => 'product',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_membership_cards_enable:is(on),uni_home_membership_cards_subscriptions_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_shop_enable',
        'label'       => esc_html__( 'Show/hide WooCommerce shop section on home page', 'asana' ),
        'desc'        => '',
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_shop_title',
        'label'       => esc_html__( 'Title for the WC shop section on home page', 'asana' ),
        'desc'        => esc_html__( 'Add title for the WC shop section on home page', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_shop_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_products_type',
        'label'       => esc_html__( 'Select what products to display on home page', 'asana' ),
        'desc'        => esc_html__( 'Select an option that fits your needs. You can choose to display random products or bestsellers.', 'asana' ),
        'std'         => 'random',
        'type'        => 'select',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_shop_enable:is(on)',
        'operator'    => 'and',
        'choices'     => array(
          array(
            'value'       => '',
            'label'       => esc_html__( '-- Choose One --', 'asana' ),
            'src'         => ''
          ),
          array(
            'value'       => 'random',
            'label'       => esc_html__( 'Random', 'asana' ),
            'src'         => ''
          ),
          array(
            'value'       => 'bestsellers',
            'label'       => esc_html__( 'Bestsellers', 'asana' ),
            'src'         => ''
          ),
          array(
            'value'       => 'featured-desc',
            'label'       => esc_html__( 'Only featured sorted by date', 'asana' ),
            'src'         => ''
          ),
          array(
            'value'       => 'featured-random',
            'label'       => esc_html__( 'Only featured sorted randomly', 'asana' ),
            'src'         => ''
          ),
          array(
            'value'       => 'most-rated',
            'label'       => esc_html__( 'Products with the highest rating first', 'asana' ),
            'src'         => ''
          )
        )
      ),
      array(
        'id'          => 'uni_home_products_number',
        'label'       => esc_html__( 'Number of products to display', 'asana' ),
        'desc'        => esc_html__( 'Specify the number of products to be displayed on the home page. Default is "8".', 'asana' ),
        'std'         => '8',
        'type'        => 'numeric-slider',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '4,40,4',
        'class'       => '',
        'condition'   => 'uni_home_shop_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_blog_enable',
        'label'       => esc_html__( 'Show/hide a blog section on home page', 'asana' ),
        'desc'        => '',
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_blog_title',
        'label'       => esc_html__( 'Title for the blog section on home page', 'asana' ),
        'desc'        => esc_html__( 'Add title for the blog section on home page', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_blog_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_textblock',
        'label'       => esc_html__( 'Classes Textblock', 'asana' ),
        'desc'        => esc_html__( 'Below are some settings for Classes block on the homepage.', 'asana' ),
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_classes_enable',
        'label'       => esc_html__( 'Show/hide Classes block on home page?', 'asana' ),
        'desc'        => '',
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_classes_bg',
        'label'       => esc_html__( 'Image for Classes block on home page', 'asana' ),
        'desc'        => esc_html__( 'Upload an image for Classes block on home page', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => 'uni_home_classes_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_classes_small_title',
        'label'       => esc_html__( 'Small title for Classes block on home page', 'asana' ),
        'desc'        => esc_html__( 'Add small title for Classes block on home page. Default text is "classes".', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_classes_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_classes_title',
        'label'       => esc_html__( 'Title for Classes block on home page', 'asana' ),
        'desc'        => esc_html__( 'Add title for Classes block on home page', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_classes_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_classes_button_uri',
        'label'       => esc_html__( 'URI for button for Classes block on home page', 'asana' ),
        'desc'        => esc_html__( 'Add URI for a button for Classes block on home page. Leave blank to hide this button.', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_classes_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_home_classes_button_title',
        'label'       => esc_html__( 'Title for button for Classes block on home page', 'asana' ),
        'desc'        => esc_html__( 'Add title for a button for Classes block on home page. Default text is "view classes".', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'uni_home_classes_enable:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_coordinates',
        'label'       => esc_html__( 'Google map coordinates', 'asana' ),
        'desc'        => esc_html__( 'For example: "41.404182,2.199451"', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'contact',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_zoom',
        'label'       => esc_html__( 'Google map zoom', 'asana' ),
        'desc'        => '',
        'std'         => '14',
        'type'        => 'select',
        'section'     => 'contact',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'choices'     => array(
          array(
            'value'       => '6',
            'label'       => '6',
            'src'         => ''
          ),
          array(
            'value'       => '7',
            'label'       => '7',
            'src'         => ''
          ),
          array(
            'value'       => '8',
            'label'       => '8',
            'src'         => ''
          ),
          array(
            'value'       => '9',
            'label'       => '9',
            'src'         => ''
          ),
          array(
            'value'       => '10',
            'label'       => '10',
            'src'         => ''
          ),
          array(
            'value'       => '11',
            'label'       => '11',
            'src'         => ''
          ),
          array(
            'value'       => '12',
            'label'       => '12',
            'src'         => ''
          ),
          array(
            'value'       => '13',
            'label'       => '13',
            'src'         => ''
          ),
          array(
            'value'       => '14',
            'label'       => '14',
            'src'         => ''
          ),
          array(
            'value'       => '15',
            'label'       => '15',
            'src'         => ''
          ),
          array(
            'value'       => '16',
            'label'       => '16',
            'src'         => ''
          ),
          array(
            'value'       => '17',
            'label'       => '17',
            'src'         => ''
          ),
        )
      ),
      array(
        'id'          => 'uni_address',
        'label'       => esc_html__( 'Address to be displayed on the "Contact Us" page', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'contact',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_phone',
        'label'       => esc_html__( 'Phone number to be displayed on the "Contact Us" page', 'asana' ),
        'desc'        => esc_html__( 'You may use html tags: <code>br, em, strong</code>.', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'contact',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_email',
        'label'       => esc_html__( 'Email to be displayed on the "Contact Us" page', 'asana' ),
        'desc'        => esc_html__( 'Also an information submitted via contact form will be sent to this email address. If no email is defined, admin email of the website will be used.', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'contact',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_contact_form_seven_id',
        'label'       => esc_html__( 'CF7 form ID for Contact page', 'asana' ),
        'desc'        => esc_html__( 'Also you can utilise Contact Form 7 form instead of built-in form. Just activate your Contact Form 7 plugin and define here the ID of the form.', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'contact',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_mailchimp_footer_enable',
        'label'       => esc_html__( 'Show/hide Mailchimp subscription form in the footer (affects all pages)?', 'asana' ),
        'desc'        => '',
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'mailchimp',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_mailchimp_events_enable',
        'label'       => esc_html__( 'Show/hide block with Mailchimp subscription form on "Events" page?', 'asana' ),
        'desc'        => '',
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'mailchimp',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_subscribe_header_bg',
        'label'       => esc_html__( 'Image in the background of "Subscribe" block', 'asana' ),
        'desc'        => esc_html__( 'Image in the background of block with Mailchimp subscription form on "Events" page', 'asana' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'mailchimp',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_subscribe_header_title',
        'label'       => esc_html__( 'Title in "Subscribe" block', 'asana' ),
        'desc'        => esc_html__( 'Title in block with Mailchimp subscription form on "Events" page', 'asana' ),
        'std'         => 'subscribe to our newsletter',
        'type'        => 'text',
        'section'     => 'mailchimp',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_subscribe_header_subtitle',
        'label'       => esc_html__( 'Subtitle in "Subscribe" block', 'asana' ),
        'desc'        => esc_html__( 'Subtitle in block with Mailchimp subscription form on "Events" page', 'asana' ),
        'std'         => 'Subscribe and take all information about our latest events',
        'type'        => 'text',
        'section'     => 'mailchimp',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_mailchimp_api_key',
        'label'       => esc_html__( 'MailChimp API Key', 'asana' ),
        'desc'        => esc_html__( 'Add your MailChimp API Key', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'mailchimp',
        'rows'        => '5',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_mailchimp_list_id',
        'label'       => esc_html__( 'MailChimp List ID', 'asana' ),
        'desc'        => esc_html__( 'Add your MailChimp List ID', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'mailchimp',
        'rows'        => '5',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_fb_app_id',
        'label'       => esc_html__( 'Facebook application ID', 'asana' ),
        'desc'        => esc_html__( 'In order to use the built-in FB share link you must create an application on https://developers.facebook.com/ and add its ID here.', 'asana' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'socialapp',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_fb_share_link_enable',
        'label'       => esc_html__( 'Enable/disable Facebook share link', 'asana' ),
        'desc'        => esc_html__( 'Enable/disable Facebook share link everywhere (below posts, products)', 'asana' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'socialapp',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_twi_share_link_enable',
        'label'       => esc_html__( 'Enable/disable Twitter Tweet link', 'asana' ),
        'desc'        => esc_html__( 'Enable/disable Twitter Tweet link everywhere (below posts, products)', 'asana' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'socialapp',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_gplus_share_link_enable',
        'label'       => esc_html__( 'Enable/disable Google+ share link', 'asana' ),
        'desc'        => esc_html__( 'Enable/disable Google+ share link everywhere (below posts, products)', 'asana' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'socialapp',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_pi_share_link_enable',
        'label'       => esc_html__( 'Enable/disable Pinterest share link', 'asana' ),
        'desc'        => esc_html__( 'Enable/disable Pinterest share link everywhere (below posts, products)', 'asana' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'socialapp',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_socials_textblock',
        'label'       => esc_html__( 'Socials Textblock', 'asana' ),
        'desc'        => esc_html__( 'Below you can add links to your social profiles. The icon of certain social media will appear only if an uri added and saved to this field.', 'asana' ),
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_email_link',
        'label'       => esc_html__( 'Add an Email link', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_fb_link',
        'label'       => esc_html__( 'Add a link to Facebook profile', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_tw_link',
        'label'       => esc_html__( 'Add a link to Twitter account', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_gp_link',
        'label'       => esc_html__( 'Add a link to Google Plus profile', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_in_link',
        'label'       => esc_html__( 'Add a link to Instagram profile', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_li_link',
        'label'       => esc_html__( 'Add a link to LinkedIn profile', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_pi_link',
        'label'       => esc_html__( 'Add a link to Pinterest profile', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_bl_link',
        'label'       => esc_html__( 'Add a link to Bloglovin account', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_fs_link',
        'label'       => esc_html__( 'Add a link to Foursquare profile', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_fl_link',
        'label'       => esc_html__( 'Add a link to Flickr profile', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_dr_link',
        'label'       => esc_html__( 'Add a link to Dribble profile', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_be_link',
        'label'       => esc_html__( 'Add a link to Behance profile', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_youtube_link',
        'label'       => esc_html__( 'Add a link to Youtube profile', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'uni_vk_link',
        'label'       => esc_html__( 'Add a link to Vkontakte profile', 'asana' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
    )
  );

  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( 'option_tree_settings', $custom_settings );
  }

}
?>